@@ -1,49 +1,50 @@
-## ----pkgmaker_preamble, echo=FALSE, results='asis'-----------------------
-pkgmaker::latex_preamble()
+## ----pkgmaker_preamble, echo=FALSE, results='asis'----------------------------
+library(NMF)
+latex_preamble()
 if(!requireNamespace("Biobase")) BiocManager::install("Biobase")
 
-## ----bibliofile, echo=FALSE, results='asis'------------------------------
-pkgmaker::latex_bibliography('NMF')	
+## ----bibliofile, echo=FALSE, results='asis'-----------------------------------
+latex_bibliography('NMF')	
 
-## ----options, include=FALSE, verbose=TRUE--------------------------------
+## ----options, include=FALSE, verbose=TRUE-------------------------------------
 #options(prompt=' ')
 #options(continue=' ')
 set.seed(123456)
-library(NMF)
 
-## ----data----------------------------------------------------------------
+## ----data---------------------------------------------------------------------
 # random data that follow an 3-rank NMF model (with quite some noise: sd=2)
-X <- syntheticNMF(100, 3, 20, noise=2)
+X <- syntheticNMF(100, 3, 20, noise=2, factors = TRUE)
+Xmat <- X[[1]]
 
 # row annotations and covariates
-n <- nrow(X)
+n <- nrow(Xmat)
 d <- rnorm(n)
 e <- unlist(mapply(rep, c('X', 'Y', 'Z'), 10))
 e <- c(e, rep(NA, n-length(e)))
 rdata <- data.frame(Var=d, Type=e)
 
 # column annotations and covariates
-p <- ncol(X)
+p <- ncol(Xmat)
 a <- sample(c('alpha', 'beta', 'gamma'), p, replace=TRUE)
 # define covariates: true groups and some numeric variable
 c <- rnorm(p)
 # gather them in a data.frame
 covariates <- data.frame(a, X$pData, c)
 
-## ----figoptions, include=FALSE-------------------------------------------
+## ----figoptions, include=FALSE------------------------------------------------
 library(knitr)
 opts_chunk$set(fig.width=14, fig.height=7)
 
-## ----heatmap_data--------------------------------------------------------
+## ----heatmap_data-------------------------------------------------------------
 par(mfrow=c(1,2))
-aheatmap(X, annCol=covariates, annRow=X$fData)
-aheatmap(X)
+aheatmap(Xmat, annCol=covariates, annRow=X$fData)
+aheatmap(Xmat)
 
-## ----model, cache=TRUE---------------------------------------------------
-res <- nmf(X, 3, nrun=10)
+## ----model, cache=TRUE--------------------------------------------------------
+res <- nmf(Xmat, 3, nrun=10)
 res
 
-## ----coefmap_res, fig.keep='last'----------------------------------------
+## ----coefmap_res, fig.keep='last'---------------------------------------------
 opar <- par(mfrow=c(1,2))
 # coefmap from multiple run fit: includes a consensus track
 coefmap(res)
@@ -51,14 +52,14 @@ coefmap(res)
 coefmap(minfit(res))
 par(opar)
 
-## ----coefmap_default, eval=FALSE-----------------------------------------
+## ----coefmap_default, eval=FALSE----------------------------------------------
 #  Rowv = NA
 #  Colv = TRUE
 #  scale = 'c1'
 #  color = 'YlOrRd:50'
 #  annCol = predict(object) + predict(object, 'consensus')
 
-## ----coefmap_custom, fig.keep='last', tidy=FALSE-------------------------
+## ----coefmap_custom, fig.keep='last', tidy=FALSE------------------------------
 opar <- par(mfrow=c(1,2))
 # removing all automatic annotation tracks
 coefmap(res, tracks=NA)
@@ -70,7 +71,7 @@ coefmap(res, Colv = 'euclidean'
 	, info = TRUE)
 par(opar)
 
-## ----basismap_res, fig.keep='last'---------------------------------------
+## ----basismap_res, fig.keep='last'--------------------------------------------
 opar <- par(mfrow=c(1,2))
 # default plot
 basismap(res)
@@ -78,13 +79,13 @@ basismap(res)
 basismap(res, main="Metagenes", annRow=list(d, e), tracks=c(Metagene=':basis'))
 par(opar)
 
-## ----basismap_default, eval=FALSE----------------------------------------
+## ----basismap_default, eval=FALSE---------------------------------------------
 #  Colv = NA
 #  scale = 'r1'
 #  color = 'YlOrRd:50'
 #  annRow = predict(object, 'features')
 
-## ----consensusmap_res, fig.keep='last'-----------------------------------
+## ----consensusmap_res, fig.keep='last'----------------------------------------
 opar <- par(mfrow=c(1,2))
 # default plot
 consensusmap(res)
@@ -94,32 +95,32 @@ consensusmap(res, annCol=covariates, annColors=list(c='blue')
 		, sub='Consensus matrix and all covariates')
 par(opar)
 
-## ----cmap_default, eval=FALSE--------------------------------------------
+## ----cmap_default, eval=FALSE-------------------------------------------------
 #  distfun = function(x) as.dist(1-x) # x being the consensus matrix
 #  hclustfun = 'average'
 #  Rowv = TRUE
 #  Colv = "Rowv"
 #  color = '-RdYlBu'
 
-## ----estimate, cache=TRUE------------------------------------------------
-res2_7 <- nmf(X, 2:7, nrun=10, .options='v')
+## ----estimate, cache=TRUE-----------------------------------------------------
+res2_7 <- nmf(Xmat, 2:7, nrun=10, .options='v')
 class(res2_7)
 
-## ----consensusmap_estimate, fig.keep='last'------------------------------
+## ----consensusmap_estimate, fig.keep='last'-----------------------------------
 consensusmap(res2_7)
 
-## ----fit_methods, cache=TRUE---------------------------------------------
-res_methods <- nmf(X, 3, list('lee', 'brunet', 'nsNMF'), nrun=10)
+## ----fit_methods, cache=TRUE--------------------------------------------------
+res_methods <- nmf(Xmat, 3, list('lee', 'brunet', 'nsNMF'), nrun=10)
 class(res_methods)
 
-## ----consensusmap_methods, fig.width=10, fig.height=7, fig.keep='last'----
+## ----consensusmap_methods, fig.width=10, fig.height=7, fig.keep='last'--------
 consensusmap(res_methods)	
 
-## ----demo_hm, eval=FALSE-------------------------------------------------
+## ----demo_hm, eval=FALSE------------------------------------------------------
 #  demo('aheatmap')
 #  # or
 #  demo('heatmaps')
 
-## ----sessionInfo, echo=FALSE, results='asis'-----------------------------
+## ----sessionInfo, echo=FALSE, results='asis'----------------------------------
 toLatex(sessionInfo())
 
